==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_results/mp0024_001/MP0024_GetWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0024_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="act_has_trans" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="standwo_has_activity" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="equip_in_mec_wo" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0024_GetWorkOrder_001_Result")
public class MP0024_GetWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;
    @XmlAttribute(name = "act_has_trans")
    protected String act_Has_Trans;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;
    @XmlAttribute(name = "standwo_has_activity")
    protected String standwo_Has_Activity;
    @XmlAttribute(name = "equip_in_mec_wo")
    protected String equip_In_Mec_Wo;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Gets the value of the multiorg property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Sets the value of the multiorg property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

    /**
     * Gets the value of the act_Has_Trans property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAct_Has_Trans() {
        if (act_Has_Trans == null) {
            return "false";
        } else {
            return act_Has_Trans;
        }
    }

    /**
     * Sets the value of the act_Has_Trans property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAct_Has_Trans(String value) {
        this.act_Has_Trans = value;
    }

    /**
     * Gets the value of the jtauth_Can_Update property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Sets the value of the jtauth_Can_Update property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

    /**
     * Gets the value of the standwo_Has_Activity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStandwo_Has_Activity() {
        if (standwo_Has_Activity == null) {
            return "false";
        } else {
            return standwo_Has_Activity;
        }
    }

    /**
     * Sets the value of the standwo_Has_Activity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStandwo_Has_Activity(String value) {
        this.standwo_Has_Activity = value;
    }

    /**
     * Gets the value of the equip_In_Mec_Wo property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEquip_In_Mec_Wo() {
        if (equip_In_Mec_Wo == null) {
            return "false";
        } else {
            return equip_In_Mec_Wo;
        }
    }

    /**
     * Sets the value of the equip_In_Mec_Wo property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEquip_In_Mec_Wo(String value) {
        this.equip_In_Mec_Wo = value;
    }

}

==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_results/mp0024_001/MP0024_GetWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp0024_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_results/MP0024_001}ResultData"/>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="act_has_trans" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="standwo_has_activity" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="equip_in_mec_wo" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0024_GetWorkOrder_001_Result")
public class MP0024_GetWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;
    @XmlAttribute(name = "act_has_trans")
    protected String act_Has_Trans;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;
    @XmlAttribute(name = "standwo_has_activity")
    protected String standwo_Has_Activity;
    @XmlAttribute(name = "equip_in_mec_wo")
    protected String equip_In_Mec_Wo;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link ResultData }
     *     
     */
    public ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link ResultData }
     *     
     */
    public void setResultData(ResultData value) {
        this.resultData = value;
    }

    /**
     * Obtient la valeur de la propriété multiorg.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Définit la valeur de la propriété multiorg.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

    /**
     * Obtient la valeur de la propriété act_Has_Trans.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAct_Has_Trans() {
        if (act_Has_Trans == null) {
            return "false";
        } else {
            return act_Has_Trans;
        }
    }

    /**
     * Définit la valeur de la propriété act_Has_Trans.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAct_Has_Trans(String value) {
        this.act_Has_Trans = value;
    }

    /**
     * Obtient la valeur de la propriété jtauth_Can_Update.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Définit la valeur de la propriété jtauth_Can_Update.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

    /**
     * Obtient la valeur de la propriété standwo_Has_Activity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStandwo_Has_Activity() {
        if (standwo_Has_Activity == null) {
            return "false";
        } else {
            return standwo_Has_Activity;
        }
    }

    /**
     * Définit la valeur de la propriété standwo_Has_Activity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStandwo_Has_Activity(String value) {
        this.standwo_Has_Activity = value;
    }

    /**
     * Obtient la valeur de la propriété equip_In_Mec_Wo.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEquip_In_Mec_Wo() {
        if (equip_In_Mec_Wo == null) {
            return "false";
        } else {
            return equip_In_Mec_Wo;
        }
    }

    /**
     * Définit la valeur de la propriété equip_In_Mec_Wo.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEquip_In_Mec_Wo(String value) {
        this.equip_In_Mec_Wo = value;
    }

}
